@@ -186,6 +186,24 @@ class UsortStringFunctionalTest(unittest.TestCase):
             """,
         )
 
+    def test_semicolons(self) -> None:
+        self.assertUsortResult(
+            """
+                import zipfile
+                import re
+                import sys; print(sys)
+                import urllib
+                import difflib
+            """,
+            """
+                import re
+                import zipfile
+                import sys; print(sys)
+                import difflib
+                import urllib
+            """,
+        )
+
     def test_dot_handling(self) -> None:
         # Test that 'from .. import b' comes before 'from ..a import foo'
         self.assertUsortResult(
@@ -391,29 +409,31 @@ numpy = ["numpy", "pandas"]
     def test_multi_line_maintain(self) -> None:
         self.assertUsortResult(
             """
-                from fuzz import buzz
+                from phi import rho
                 # one
-                from foo import (  # two
+                from alpha import (  # two
                     # three
-                    bar,  # four
+                    beta,  # four
                     # five
-                    baz # six
+                    delta # six
                     , # seven
-                    # eight
-                )  # nine
-                # ten
+                    gamma # eight
+                    # nine
+                )  # ten
+                # eleven
             """,
             """
                 # one
-                from foo import (  # two
+                from alpha import (  # two
                     # three
-                    bar,  # four
+                    beta,  # four
                     # five
-                    baz,  # six  # seven
-                    # eight
-                )  # nine
-                from fuzz import buzz
-                # ten
+                    delta,  # six  # seven
+                    gamma,  # eight
+                    # nine
+                )  # ten
+                from phi import rho
+                # eleven
             """,
         )
 
@@ -421,30 +441,32 @@ numpy = ["numpy", "pandas"]
         self.assertUsortResult(
             """
                 def foo():
-                    from fuzz import buzz
+                    from phi import rho
                     # one
-                    from foo import (  # two
+                    from alpha import (  # two
                         # three
-                        bar,  # four
+                        beta,  # four
                         # five
-                        baz # six
+                        delta # six
                         , # seven
-                        # eight
-                    )  # nine
-                    # ten
+                        gamma # eight
+                        # nine
+                    )  # ten
+                    # eleven
             """,
             """
                 def foo():
                     # one
-                    from foo import (  # two
+                    from alpha import (  # two
                         # three
-                        bar,  # four
+                        beta,  # four
                         # five
-                        baz,  # six  # seven
-                        # eight
-                    )  # nine
-                    from fuzz import buzz
-                    # ten
+                        delta,  # six  # seven
+                        gamma,  # eight
+                        # nine
+                    )  # ten
+                    from phi import rho
+                    # eleven
             """,
         )
 
@@ -453,20 +475,22 @@ numpy = ["numpy", "pandas"]
             """
                 from fuzz import buzz
                 # 1
-                from foo import (  # 2
+                from a import (  # 2
                     # 3
-                    bar,  # 4
+                    b,  # 4
                     # 5
-                    baz # 6
+                    c # 6
                     , # 7
-                )  # 8
-                # 9
+                    d # 8
+                    # 9
+                )  # 10
+                # 11
             """,
             """
                 # 1
-                from foo import bar, baz  # 2  # 3  # 4  # 5  # 6  # 7  # 8
+                from a import b, c, d  # 2  # 3  # 4  # 5  # 6  # 7  # 8  # 9  # 10
                 from fuzz import buzz
-                # 9
+                # 11
             """,
         )
 
@@ -542,6 +566,24 @@ numpy = ["numpy", "pandas"]
             """,
         )
 
+    def test_multi_line_expand_but_not_very_long(self) -> None:
+        """
+        This test makes sure indentation is taken into account properly.
+        Without indentation, these lines wouldn't be too long.
+        """
+        self.assertUsortResult(
+            """
+                if foo:
+                    from aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa import bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb
+            """,
+            """
+                if foo:
+                    from aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa import (
+                        bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb,
+                    )
+            """,
+        )
+
     def test_multi_line_expand_inner_function(self) -> None:
         self.assertUsortResult(
             """
